package org.alltimeflashdreamer.dimdom;

import java.io.*;

/**
 * Title: DimDomException<br>
 * Description: This excpeption is designed to handle problems that
 * occur(red) while processing a DimDom template / commands pair.
 *
 * @author    Copyright (c) 2002 by <a href="mailto:florian@steinsiepe.ch">
 *      Florian Steinsiepe</a>
 * @version   0.8.2
 */

public class DimDomException extends Exception
{
    private String sMessage;
    private Exception e;


    /**
     * Constructor with a message text only.
     *
     * @param sMessage  the error message
     */
    public DimDomException( String sMessage )
    {
        this( sMessage, null );
    }

    /**
     * Constructor with a Throwable only. During printing of the message text,
     * the stack trace of the Throwable is printed as the message text.
     *
     * @param e  the root cause of the DimDomException
     */
    public DimDomException( Exception e )
    {
        this( null, e );
    }

    /**
     * Constructor with a message text and a Throwable. During printing of the
     * message text, the value of sMessage, followed by the stack trace of this
     * class itself, followed by the stack trace of the Throwable is printed as
     * the message text.
     *
     * @param sMessage  the error message
     * @param e  the root cause of the DimDomException
     */
    public DimDomException( String sMessage, Exception e )
    {
        this.sMessage = sMessage;
        this.e = e;
    }

    /**
     * Override of superclass' method, calls getMessage().
     *
     * @return   the error message
     */
    public String toString()
    {
        return getMessage();
    }

    /**
     * Override of superclass' method, does what is described in the constructor
     * that was called.
     *
     * @return   the error message
     */
    public String getMessage()
    {
        final String NESTEDEXCEPTION = "Nested exception is: ";
        final String NODESCRIPTION = "(no description)";
        String sReturnValue = "";
        String thisClassName = this.getClass().getName() + ": ";

        //case 1: only message text
        if ( ( sMessage != null ) && ( e == null ) )
            sReturnValue = thisClassName + sMessage;
        //case 2: only throwable
        else if ( ( sMessage == null ) && ( e != null ) )
            sReturnValue = thisClassName + NODESCRIPTION + "\n" + NESTEDEXCEPTION + "\n" +
                    formatStackTrace( e );
        //case 3: both message and throwable
        else if ( ( sMessage != null ) && ( e != null ) )
            sReturnValue += thisClassName + sMessage + "\n" + NESTEDEXCEPTION + "\n" + formatStackTrace( e );

        return sReturnValue;
    }

    /**
     * Loads the stack trace of the Throwable into a StringWriter and returns
     * the toString value of the writer.
     *
     * @param e  the exception to print the stack trace of
     * @return   the stack trace as a platform-specifically formatted string
     */
    private String formatStackTrace( Exception e )
    {
        StringWriter s = new StringWriter();
        e.printStackTrace( new PrintWriter( s ) );
        return ( e.getClass().getName() + ": " + s.toString() );
    }
}
