package org.alltimeflashdreamer.dimdom;

import java.net.URL;
import org.w3c.dom.Document;

/**
 * Title: SimpleSiteData<br>
 * Description: This simple implementation of AbstractXHTMLSiteData provides two
 * constructors, one for each of the two parameters of those at least one must
 * be defined. It is part of the reference implementation and can be extended in
 * case more or different functionality shall be added.
 *
 * @author    Copyright (c) 2002 by <a href="mailto:florian@steinsiepe.ch">
 *      Florian Steinsiepe</a>
 * @version   0.8.2
 */

public class SimpleSiteData extends AbstractXHTMLSiteData
{
    /** the processor class name, to be returned to the DimDom class */
    private final static String XHTMLDOCUMENTCLASSNAME = "org.alltimeflashdreamer.dimdom.SimpleDocument";
	/** the test DOM which is used to test the commands of the user */
    private Document testDoc;

    /**
     * Constructor parses a file source, if the given String doesn't contain "
     * <html>", else the given String is assumed to be an XHTML string and is
     * parsed itself (note: maximum lenght of java.lang.String is the
     * limitation!).
     *
     * @param sInput  the name of the template file or the string to be parsed
     */
    public SimpleSiteData( String sInput )
    {
        if ( sInput.toLowerCase().indexOf( "<html>" ) >= 0 )
            this.setString( sInput );
        else
            this.setTemplateFilename( sInput );
        testDoc = DimDom.getTestDocument();
    }

    /**
     * Constructor needed to parse an URL source.
     *
     * @param url  the URL to read from
     */
    public SimpleSiteData( URL url )
    {
        this.setURL( url );
    }

    /**
     * Returns the XHTMLDocument implementing instance of the reference
     * implementation.
     *
     * @return   SimpleSiteData uses "org.alltimeflashdreamer.dimdom.SimpleDocument"
     */
    public String getXHTMLDocumentClassName()
    {
        return XHTMLDOCUMENTCLASSNAME;
    }

    /**
     * Creates a new command object, after appending the previous one to the
     * internal, ordered list of commands (only if not the first).
     *
     * @param sNodeIdentifier
     * @return  the next freshly created DimDom command object, ready to
	 *          be "dynamized"
     */
    public DimDomNodeImpl createDimDomCommand( String sNodeIdentifier )
    {
        DimDomNodeImpl ddni = new DimDomNodeImpl( testDoc, sNodeIdentifier );
        this.vDimDomNodeImpls.add( ddni );
        return ddni;
    }
}
