package org.alltimeflashdreamer.dimdom;

import java.io.*;
import org.xml.sax.SAXException;

/**
 * Title: XHTMLDocument<br>
 * Description: This interface declares the two central methods of the DimDom
 * engine: print and setSiteData. Each template/command pair that shall be
 * processed by the DimDom engine needs to implement this interface which
 * makes a XHTMLDocument out of it. This means that the underlying
 * org.w3c.dom.Document instance represents pure XML (with HTML tag names),
 * is dynamizable and printable using the DOMFormatter.
 *
 * @author    Copyright (c) 2002 by <a href="mailto:florian@steinsiepe.ch">
 *      Florian Steinsiepe</a>
 * @version   0.8.2
 */

public interface XHTMLDocument
{
    /**
     * Forces the HTMLDocument to print out its dynamically adapted content as a
     * String.<br>
     * The exception that may be thrown is one of the processing of the dynamic
     * data or of the HTMLFormatter.
     *
     * @return                     the full HTML string
     * @exception IOException      thrown by the parser (input source)
     * @exception DimDomException  thrown by the processor, if something is/went
     *      wrong
     */
    public String print()
        throws IOException, DimDomException;

    /**
     * This method is (typically) called by the servlet instantiating a specific
     * subclass of this class that needs to be filled with dynamic data.<br>
     * It is defined within a separate interface to hide the functionality of
     * implementing classes to the servlet programmer, because the updating
     * process is uni-directional (thread safety!).
     *
     * @param siteData             an instance of a class implementing
     *      org.alltimeflashdreamer.dimdom.XHTMLSiteData
     * @exception SAXException     thrown by the parser
     * @exception IOException      thrown by the parser (input source)
     * @exception DimDomException  thrown by the processor, if something is/went
     *      wrong
     */
    public void setSiteData( XHTMLSiteData siteData )
        throws SAXException, IOException, DimDomException;
}
