package org.alltimeflashdreamer.dimdom;

import java.net.URL;

/**
 * Title: XHTMLSiteData<br>
 * Description: This is the client interface of the DimDom engine. Each class
 * that shall serve values/commands has to implement at least those interfaces,
 * although it is absolutely recommended to extend AbstractSiteData or even
 * SimpleSiteData, unless you'd like to completely rewrite the DimDom engine.
 * <br>
 * Note: The methods defined in this interface are those needed by the DimDom
 * class <i>only</i> . Each further code is implementation specified and
 * therefore not listed here.
 *
 * @author    Copyright (c) 2002 by <a href="mailto:florian@steinsiepe.ch">
 *      Florian Steinsiepe</a>
 * @version   0.8.2
 */

public interface XHTMLSiteData
{
    /**
     * Returns the identifier which is used by the DimDom to know which template
     * source is now to be filled with dynamic data.
     *
     * @return   an identifying string
     */
    public String getIdentifier();

    /**
     * This method returns the fully qualified class name of the XHTMLDocument
     * implementing class. This method allows to exchange the template
     * processor. The specified class must be available for the JVM. If not,
     * DimDom gets some ClassNotFoundException which is wrapped in the
     * DimDomException declared in the print method of the DimDom class.
     *
     * @return   the name of the available template processor class; for
     *      SimpleSiteData, this is "org.alltimeflashdreamer.dimdom.SimpleXHTMLDocument"
     */
    public String getXHTMLDocumentClassName();

    /**
     * Returns the next implementing object of the DimDomNode interface, to
     * allow the DimDom engine to process the next node (or the next clone of a
     * micro-template node).
     *
     * @return   the next instance of the DimDomNode implementing class or null,
     *      if there aren't more such instances
     */
    public DimDomNode getNextDimDomNode();

    /**
     * Returns the source string to be parsed.
     *
     * @return   the source string, if one is set, or null
     */
    public String getString();

    /**
     * Returns the template's file name of the template file to be parsed.
     *
     * @return   the template's file name, if one is set, or null
     */
    public String getTemplateFileName();

    /**
     * Returns the source URL to parse from.
     *
     * @return   the URL, if one is set, or null
     */
    public URL getURL();
}
