package org.alltimeflashdreamer.dimdom.websitetester;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import org.alltimeflashdreamer.dimdom.*;

/**
 * Title: AbstractXHTMLServlet<br>
 * Description: This servlet is the superclass of each Website Tester servlet.
 * It collects the common methods and declares the post method abstractly, so
 * that extending servlets implement this method.
 *
 * @author    Copyright (c) 2002 by <a href="mailto:florian@steinsiepe.ch">
 *      Florian Steinsiepe</a>
 * @version   0.8.2
 */

abstract class AbstractXHTMLServlet extends HttpServlet
{
    /**
     * We don't get, we post!
     *
     * @param req                the request object to read URL stuff from
     * @param res                the response object to send stuff to
     * @throws ServletException  as defined in the superclass
     * @throws IOException       as defined in the superclass
     */
    public void doGet( HttpServletRequest req, HttpServletResponse res )
        throws ServletException, IOException
    {
        doPost( req, res );
    }

    /**
     * (abstract declaration, to be implemented by extending classes)
     *
     * @param req                the request object to read URL stuff from
     * @param res                the response object to send stuff to
     * @throws ServletException  as defined in the superclass
     * @throws IOException       as defined in the superclass
     */
    public abstract void doPost( HttpServletRequest req, HttpServletResponse res )
        throws ServletException, IOException;

    /**
     * Initializes the appropriate procedure to show the given error to the
     * user.
     *
     * @param iWhichError        id from ErrorSiteProcessor class
     * @param res                the response to write to
     * @param ex                 the exception to show
     * @throws ServletException  if the ErrorSiteProcessor itself catches an
     *      exception
     * @throws IOException       if something with the writing of the output to
     *      the client doesn't work
     */
    protected void showErrorSite( int iWhichError,
            HttpServletResponse res, Exception ex )
        throws ServletException, IOException
    {
        res.setContentType( "text/html" );
        PrintWriter out = res.getWriter();
        out.println( new ErrorSiteProcessor( iWhichError, ex ).print() );
        out.close();
    }

    /**
     * Simply prints the HTML output, generated by the DimDom.print method. If
     * this leads to an exception, the related error error site is shown.
     *
     * @param res                the response object to write the output to
     * @param siteData           the DimDom command object to process
     * @throws ServletException  if the ErrorSiteProcessor itself catches an
     *      exception
     * @throws IOException       if something with the writing of the output to
     *      the client doesn't work
     */
    protected void printSite( HttpServletResponse res, XHTMLSiteData siteData )
        throws ServletException, IOException
    {
        try
        {
            res.setContentType( "text/html" );
            PrintWriter out = res.getWriter();
            out.println( DimDom.print( siteData ) );
            out.close();
        } catch ( Exception ex )
        {
            showErrorSite( ErrorSiteProcessor.SITEPRINTERROR, res, ex );
        }
    }
}
