package org.alltimeflashdreamer.dimdom.websitetester;

import org.alltimeflashdreamer.dimdom.*;

/**
 * Title: SampleSiteProcessor<br>
 * Description: This is one of the reference implementations of the DimDom Website
 * Tester application. It is designed to fill the id nodes defined in the <i>
 * default</i> XHTML content of the text area on the first site. Therefore, if
 * this XHTML input changes, the behaviour of the engine may become
 * inpredictable.<br>
 * Everything is done within the constructor <i>without arguments</i> , to allow
 * the XHTMLProcessorServlet to get this class via the newInstance method.<br>
 * The values to set are hard-coded.
 *
 * @author    Copyright (c) 2002 by <a href="mailto:florian@steinsiepe.ch">
 *      Florian Steinsiepe</a>
 * @version   0.8.2
 */

public class SampleSiteProcessor extends SimpleSiteData
{
    /**
     * The constructor builds a simple list of DimDom commands which are to be
     * processed using the XHTML input string from the Website Tester's text
     * area input.<br>
     * The method first calls the superclass' constructor using the empty string. (This
     * isn't relevant at all, because the source will be set immediately after
     * the construction of this class). It then adds data and sets attributes to the
	 * nodes with the "id" attributes, named "title", "metaDescription", "body",
	 * "siteTitle", "imageDescription" and "image".<br>
	 * For each new command that shall be executed on a node, the createDimDomCommand
	 * method of the superclass must be called, which returns a new instance of
	 * DimDomCommandImpl, the reference implementation class of the DimDomNode
	 * interface, which is part of the specification 1.0. With this command object,
	 * one's able to use the full functionality on each of the defined nodes.<br>
	 * Because the SampleSiteProcessor is very simple, you should see the tutorial
	 * examples for more details too.
     *
     * @exception DimDomException  the exception that tells the caller that
	 *            the setting of some attribute values was illegal, i.e. the values
	 *            haven't been XHTML compliant
     */
    public SampleSiteProcessor()
        throws DimDomException
    {
		//call the empty constructor of the superclass
        super( "" );

		//add data to the "title" node
        this.createDimDomCommand( "title" ).addData( "SampleSiteProcessor's dynamic output" );

		//set the content attribute of the "metaDescription" node
        this.createDimDomCommand( "metaDescription" ).setAttribute( "content",
                "DimDom Website Tester: SampleSiteProcessor's dynamically created output" );

		//set some attributes of the "body" node
        DimDomNodeImpl ddni = this.createDimDomCommand( "body" );
        ddni.setAttribute( "bgcolor", "EEEEEE" );
        ddni.setAttribute( "text", "0000FF" );
        ddni.setAttribute( "link", "000000" );
        ddni.setAttribute( "alink", "FF0000" );
        ddni.setAttribute( "vlink", "0000FF" );

		//add data to the "siteTitle" node
        this.createDimDomCommand( "siteTitle" ).addData( "SampleSiteProcessor's dynamically created output" );

		//add data to the "imageDescription" node
        this.createDimDomCommand( "imageDescription" ).addData( "The image receives 10 DimDom commands. " +
                "In case the maximum allowed repetition count is less than this value, you'll see that " +
                "DimDom stops processing the commands as soon as this value is exceeded." );

		//repeat the "image" node 10 times and set some attributes to each copy (each second one
		//is surrounded with a border line); if the template's "dimdom" attribute allows 10 or
		//more repetitions, we'll get 10 copies, else less
        for ( int i = 0; i < 10; i++ )
        {
            ddni = this.createDimDomCommand( "image" );
            ddni.setAttribute( "src", "http://java.sun.com/images/logos/javalogo52x88.gif" );
            ddni.setAttribute( "alt", "Repetition cycle #" + ( i + 1 ) );
            ddni.setAttribute( "border", "" + ( i % 2 ) );
        }
    }
}
