package org.alltimeflashdreamer.dimdom.websitetester;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import org.alltimeflashdreamer.dimdom.*;
import org.w3c.dom.*;

/**
 * Title: XHTMLProcessorServlet<br>
 * Description: This servlet fills the DimDom XHTML input with the dynamic
 * values. It is a very basic implementation for the default textarea content.
 * If this content is modified, the behaviour of this class may be strange
 * somehow...
 *
 * @author    Copyright (c) 2002 by <a href="mailto:florian@steinsiepe.ch">
 *      Florian Steinsiepe</a>
 * @version   0.8.2
 */

public class XHTMLProcessorServlet extends AbstractXHTMLServlet
{
    /**
     * Reads the XHTML string from the URL and passes it to the XHTMLParser
     * class of DimDom. If the parser fails to build a Document out of this
     * string, it shows the processed error site. If it succeeds, it fills the
     * success site with the dynamically recognized DimDom-relevant data from
     * the template and allows the user to enter his modification parameters for
     * the processor class.<br>
     * The various input parameters are read from the
     * DimDom_WebsiteTester.properties file. The method first asks for a servlet
     * parameter named "DimDom_WebsiteTester" (case-sensitive). If this
     * parameter is found, it reads the file mentioned in this parameter, else
     * it tries to read it from the servlet's application directory. If this
     * fails too, an exception is thrown.
     *
     * @param req                the request object to read URL stuff from
     * @param res                the response object to send stuff to
     * @throws ServletException  as defined in the superclass
     * @throws IOException       as defined in the superclass
     */
    public void doPost( HttpServletRequest req, HttpServletResponse res )
        throws ServletException, IOException
    {
        //read the property file
        PropertyHandler propsHandler = new PropertyHandler( req, this.getServletContext() );
        if ( !propsHandler.hasReadingBeenSuccessful() )
        {
            showErrorSite( ErrorSiteProcessor.PROPERTYFILEERROR, res, propsHandler.getException() );
            return;
        }

        //get the URL input parameter value and add the xml and the doctype tags to it.
        String sXHTMLInput = req.getParameter( "dimdomXHTMLInput" );
        if ( ( sXHTMLInput == null ) || ( sXHTMLInput.equals( "" ) ) )
        {
            showErrorSite( ErrorSiteProcessor.MISSINGINPUTERROR, res, null );
            return;
        }
        sXHTMLInput = propsHandler.getXMLTags() + sXHTMLInput;

        //fill the DimDom command objects and set the XHTMLSiteData to docImpl
        String sProcessorClassName = req.getParameter( "processorClass" );
        SimpleSiteData siteData = null;
        try
        {
            siteData = ( SimpleSiteData )Class.forName( sProcessorClassName ).newInstance();
            siteData.setString( sXHTMLInput );
        } catch ( Exception ex )
        {
            showErrorSite( ErrorSiteProcessor.MISSINGPROCESSORCLASSERROR, res, ex );
            return;
        }

        //parse the input, if DimDom doesn't know the identifier yet and if
        //it's not the inner class of the XHTMLParserServlet (but a valid
        //SimpleSiteData instance)
        XHTMLDocument doc;
        try
        {
            if ( ( doc = DimDom.getDimDomDocument( sXHTMLInput ) ) == null )
            {
                doc = new SimpleDocument( siteData );
                DimDom.addDimDomDocument( sXHTMLInput, doc );
            }
            else
            {
                try
                {
                    SimpleDocument simpleDoc = ( SimpleDocument )doc;
                    doc.setSiteData( siteData );
                } catch ( ClassCastException cce )
                {
                    doc = new SimpleDocument( siteData );
                    DimDom.addDimDomDocument( sXHTMLInput, doc );
                }
            }
        } catch ( Exception ex )
        {
            showErrorSite( ErrorSiteProcessor.INPUTPARSERERROR, res, ex );
            return;
        }

        //pass the XHTMLSiteData to DimDom and print it out
        printSite( res, siteData );
    }
}
